@@ -1,4 +1,4 @@
 "print.varcheck" <-
 function(x, ...){
-  lapply(x[-1], print)
+  lapply(x[-1], print, ...)
 }
